==> cxf-testutils-2.0.10.1-fuse-sources.jar: org/apache/type_test/types3/StructWithMultipleSubstitutionGroups.java <==

package org.apache.type_test.types3;

import java.math.BigInteger;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for StructWithMultipleSubstitutionGroups complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StructWithMultipleSubstitutionGroups">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}double"/>
 *         &lt;element ref="{http://apache.org/type_test/types3}sg01BaseElement_A"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}unsignedLong"/>
 *         &lt;element ref="{http://apache.org/type_test/types3}sg02BaseElement_A"/>
 *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StructWithMultipleSubstitutionGroups", propOrder = {
    "varFloat",
    "sg01BaseElementA",
    "varInt",
    "sg02BaseElementA",
    "varString"
})
public class StructWithMultipleSubstitutionGroups {

    @XmlElement(namespace = "http://apache.org/type_test/types3")
    protected double varFloat;
    @XmlElementRef(name = "sg01BaseElement_A", namespace = "http://apache.org/type_test/types3", type = JAXBElement.class)
    protected JAXBElement<? extends SgBaseTypeA> sg01BaseElementA;
    @XmlElement(namespace = "http://apache.org/type_test/types3", required = true)
    protected BigInteger varInt;
    @XmlElementRef(name = "sg02BaseElement_A", namespace = "http://apache.org/type_test/types3", type = JAXBElement.class)
    protected JAXBElement<? extends SgBaseTypeA> sg02BaseElementA;
    @XmlElement(namespace = "http://apache.org/type_test/types3", required = true)
    protected String varString;

    /**
     * Gets the value of the varFloat property.
     * 
     */
    public double getVarFloat() {
        return varFloat;
    }

    /**
     * Sets the value of the varFloat property.
     * 
     */
    public void setVarFloat(double value) {
        this.varFloat = value;
    }

    /**
     * Gets the value of the sg01BaseElementA property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link SgBaseTypeA }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeC }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeB }{@code >}
     *     
     */
    public JAXBElement<? extends SgBaseTypeA> getSg01BaseElementA() {
        return sg01BaseElementA;
    }

    /**
     * Sets the value of the sg01BaseElementA property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link SgBaseTypeA }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeC }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeB }{@code >}
     *     
     */
    public void setSg01BaseElementA(JAXBElement<? extends SgBaseTypeA> value) {
        this.sg01BaseElementA = ((JAXBElement<? extends SgBaseTypeA> ) value);
    }

    /**
     * Gets the value of the varInt property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getVarInt() {
        return varInt;
    }

    /**
     * Sets the value of the varInt property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setVarInt(BigInteger value) {
        this.varInt = value;
    }

    /**
     * Gets the value of the sg02BaseElementA property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeC }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgBaseTypeA }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeB }{@code >}
     *     
     */
    public JAXBElement<? extends SgBaseTypeA> getSg02BaseElementA() {
        return sg02BaseElementA;
    }

    /**
     * Sets the value of the sg02BaseElementA property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeC }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgBaseTypeA }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeB }{@code >}
     *     
     */
    public void setSg02BaseElementA(JAXBElement<? extends SgBaseTypeA> value) {
        this.sg02BaseElementA = ((JAXBElement<? extends SgBaseTypeA> ) value);
    }

    /**
     * Gets the value of the varString property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVarString() {
        return varString;
    }

    /**
     * Sets the value of the varString property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVarString(String value) {
        this.varString = value;
    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/type_test/types3/StructWithMultipleSubstitutionGroups.java <==

package org.apache.type_test.types3;

import java.math.BigInteger;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for StructWithMultipleSubstitutionGroups complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StructWithMultipleSubstitutionGroups">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}double"/>
 *         &lt;element ref="{http://apache.org/type_test/types3}sg01BaseElement_A"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}unsignedLong"/>
 *         &lt;element ref="{http://apache.org/type_test/types3}sg02BaseElement_A"/>
 *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StructWithMultipleSubstitutionGroups", propOrder = {
    "varFloat",
    "sg01BaseElementA",
    "varInt",
    "sg02BaseElementA",
    "varString"
})
public class StructWithMultipleSubstitutionGroups {

    protected double varFloat;
    @XmlElementRef(name = "sg01BaseElement_A", namespace = "http://apache.org/type_test/types3", type = JAXBElement.class)
    protected JAXBElement<? extends SgBaseTypeA> sg01BaseElementA;
    @XmlElement(required = true)
    @XmlSchemaType(name = "unsignedLong")
    protected BigInteger varInt;
    @XmlElementRef(name = "sg02BaseElement_A", namespace = "http://apache.org/type_test/types3", type = JAXBElement.class)
    protected JAXBElement<? extends SgBaseTypeA> sg02BaseElementA;
    @XmlElement(required = true)
    protected String varString;

    /**
     * Gets the value of the varFloat property.
     * 
     */
    public double getVarFloat() {
        return varFloat;
    }

    /**
     * Sets the value of the varFloat property.
     * 
     */
    public void setVarFloat(double value) {
        this.varFloat = value;
    }

    /**
     * Gets the value of the sg01BaseElementA property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link SgBaseTypeA }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeB }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeC }{@code >}
     *     
     */
    public JAXBElement<? extends SgBaseTypeA> getSg01BaseElementA() {
        return sg01BaseElementA;
    }

    /**
     * Sets the value of the sg01BaseElementA property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link SgBaseTypeA }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeB }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeC }{@code >}
     *     
     */
    public void setSg01BaseElementA(JAXBElement<? extends SgBaseTypeA> value) {
        this.sg01BaseElementA = ((JAXBElement<? extends SgBaseTypeA> ) value);
    }

    /**
     * Gets the value of the varInt property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getVarInt() {
        return varInt;
    }

    /**
     * Sets the value of the varInt property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setVarInt(BigInteger value) {
        this.varInt = value;
    }

    /**
     * Gets the value of the sg02BaseElementA property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeC }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeB }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgBaseTypeA }{@code >}
     *     
     */
    public JAXBElement<? extends SgBaseTypeA> getSg02BaseElementA() {
        return sg02BaseElementA;
    }

    /**
     * Sets the value of the sg02BaseElementA property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeC }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgDerivedTypeB }{@code >}
     *     {@link JAXBElement }{@code <}{@link SgBaseTypeA }{@code >}
     *     
     */
    public void setSg02BaseElementA(JAXBElement<? extends SgBaseTypeA> value) {
        this.sg02BaseElementA = ((JAXBElement<? extends SgBaseTypeA> ) value);
    }

    /**
     * Gets the value of the varString property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVarString() {
        return varString;
    }

    /**
     * Sets the value of the varString property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVarString(String value) {
        this.varString = value;
    }

}
